@@ -1,7 +1,7 @@
 /**************************************************************************
 
     begin                : June 30 2004
-	version				 : 1.2 
+	version				 : 2.0 
     copyright            : (C) 2004 by Gleb Beliakov
     email                : gleb@deakin.edu.au
 
@@ -138,7 +138,7 @@ SVSetNode::SVSetNode()   { 	Init(); }
 void SVSetNode::Init() { 
 		children__=MB_BADINDEX;
 		vecnumber=MB_BADINDEX; 
-		Dval=-Infinity;	// for triangulation test
+		Dval=(float) -Infinity;	// for triangulation test
 }
 
 SVSetNode::~SVSetNode() { }
@@ -203,7 +203,7 @@ int SVSetNode::TestVectorIndex(dVec& v, siVec* index)
 int SVSetNode::TestVector(dVec& v, siVec* index)
 {
 		real u;
-		short int pos = POS_VEC(vecnumber);
+		int pos = POS_VEC(vecnumber);
 		int vecnumber_ = VEC_VEC(vecnumber);
 
 		if(IS_ROOT(vecnumber)) { // root, use index explicitly
@@ -215,7 +215,7 @@ int SVSetNode::TestVector(dVec& v, siVec* index)
 			{	return 2; }      // nonstrict dominance
 			return 1; // strict dominance
 		}
-		return 1; //should not get here
+	//	return 1; //should not get here
 }
 
 // as above but strict inequality
@@ -229,7 +229,7 @@ int SVSetNode::TestVectorIndexQ(dVec& v, siVec* index)
 
 int SVSetNode::TestVectorQ(dVec& v, siVec* index)
 {
-		short int pos = POS_VEC(vecnumber);
+		int pos = POS_VEC(vecnumber);
 		int vecnumber_ = VEC_VEC(vecnumber);
 
 		if(IS_ROOT(vecnumber)) { // root, use index explicitly
@@ -238,7 +238,7 @@ int SVSetNode::TestVectorQ(dVec& v, siVec* index)
 			if( Parent->SVectors[ vecnumber_ ].vec[pos] > v[pos]) {return 0;} //<=
 			return 1;
 		}
-		return 1; //should not get here
+//		return 1; //should not get here
 }
 
 //returns 0 if insuccessful, 1 if cond 1 is satisfied
@@ -291,13 +291,13 @@ real	SVSetNode::ComputeMaximumF(siVec* index)
 		if(a<c) a=c; // max
 		if(b>c) b=c; // min
 	}
-		Dval=a + 0.001   * (a - b  + 0.0000001); // max - min
-		return Dval;
+		Dval= (float) (a + 0.001   * (a - b  + 0.0000001)); // max - min
+		return (double) Dval;
 }
 
 real	SVSetNode::ComputeFunValue(dVec& X, siVec* index)
 {
-	real b,c,a=-Infinity;
+	real b,c=0,a=-Infinity;
 	for(int i=0;i<Parent->Dim;i++) {
 		b = Infinity;
 		for(int j=0;j<Parent->Dim;j++){
@@ -328,7 +328,7 @@ void Forest::Init()
 	Initiated=1;
 };
 
-
+/*
 int Forest::ComputeSize(SVSetNodePtr node)
 {
 	int sz=1;
@@ -356,7 +356,7 @@ int Forest::ComputeSize(SVSetNodePtr node, int not_this_child)
 	return sz;
 }
 
-
+*/
 
 
 void	Forest::AddRootNode( SVSetNodePtr node)
@@ -405,7 +405,7 @@ void	Forest::AddTree(SVSetNodePtr root)
 	*(Head.p_index) = temp_index;
 	Heads.push_back(Head);
 
-	SVSetNode* R= MBSV.GetAt(root);
+//	SVSetNode* R= MBSV.GetAt(root);
 
 	AddLeaf(root);
 }
@@ -490,8 +490,8 @@ int Forest::ProcessNode(SVSetNodePtr node, support_vector* SV, siVec* initvec)
 
 /*------------------- for indices --*/
 #ifdef TRIANGULATION1
-	UINT	idx;
-	short int Globpos;
+	UINT	idx=0;
+	int Globpos;
 	Globpos = POS_VEC(Node->vecnumber);
 
 	int Globvecnumber_ = VEC_VEC(Node->vecnumber);
@@ -601,8 +601,8 @@ int Forest::ProcessNodeDyn(SVSetNodePtr node, support_vector* SV, siVec* initvec
 	SVSetNode* Node=MBSV.GetAt(node);
 
 	short int i;
-	UINT	idx;
-	short int Globpos;
+	UINT	idx=0;
+	int Globpos;
 
 	Globpos = POS_VEC(Node->vecnumber);
 
@@ -684,7 +684,6 @@ void	Forest::PackBranch(SVSetNodePtr branch, char* buffer, int& pos)
 	int i,j;
 	sizepacked++;
 	SVSetNode* Branch=MBSV.GetAt(branch);
-//	ConstrMin* cm;
 
 
 	buffer[pos++]=CODE_EL;
@@ -753,10 +752,6 @@ void	Forest::UnPackBranch(char* buffer, int& pos, SVSetNodePtr branch)
 	SVSetNodePtr child;
 	SVSetNode* Branch=MBSV.GetAt(branch);
 
-//	ConstrMin* cm;
-//	ConstMinPtr cmP;
-
-//	UINT kil;
 
 	while(cont) {
 		i=buffer[pos++];
